@@ -3,15 +3,17 @@
 #
 #  (C) Paul Evans, 2019-2020 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.46;
+package Object::Pad 0.47;
 
 use v5.14;
 use warnings;
 
 use Carp;
 
-require XSLoader;
-XSLoader::load( __PACKAGE__, our $VERSION );
+sub dl_load_flags { 0x01 }
+
+require DynaLoader;
+__PACKAGE__->DynaLoader::bootstrap( our $VERSION );
 
 # So that feature->import will work in `class`
 require feature;
@@ -884,6 +886,10 @@ Oetiker+Partner AG L<https://www.oetiker.ch/en/>
 
 Deriv L<http://deriv.com>
 
+=item *
+
+Perl-Verein Schweiz L<https://www.perl-workshop.ch/>
+
 =back
 
 Additional details may be found at
