@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2020 -- leonerd@leonerd.org.uk
 
-package Object::Pad::MOP::Slot 0.46;
+package Object::Pad::MOP::Slot 0.47;
 
 use v5.14;
 use warnings;
@@ -57,22 +57,6 @@ instance.
 On scalar slots, this method can also act as an lvalue mutator allowing a new
 value to be set.
 
-=head2 param_name
-
-   $name = $metaslot->param_name
-
-I<Since version 0.43.>
-
-Returns the name of the parameter if the slot has one; otherwise undef.
-
-=head2 has_param
-
-   $has_param = $metaslot->has_param
-
-I<Since version 0.42.>
-
-Returns true if the slot is assigned to be a named constructor parameter.
-
 =cut
 
 =head1 AUTHOR
